#!/bin/bash
##########################################################################################
# +------------------------------------------------------------------+
# |                                                                  |
# | Copyright Yuvam Jain                         yuvamjain@gmail.com |
# +------------------------------------------------------------------+
#
# This is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  VIngios is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# ails.  You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, 101, HariOM Palace Indore.
# Software is tested with ability to make monitoring better.
# There is no claim or warranty about the other effect of individual service.
#
# Vingios Version 3.1
# Release Date : 
##################################################################

clear
VERSION=3.1
NAME=Vingios
LANG=
LC_ALL=
SETUPCONF=~/.vingios_setup.conf
YES=

## Find path to ourselves
SRCDIR=${0%/*}
if [ "$SRCDIR" = "$0" ] ; then SRCDIR=. ; fi


if [ $UID = 0 -o -n "$DESTDIR" ] ; then
    ROOT=yes
    if [ "$DESTDIR" = / ] ; then
	DESTDIR=
    fi
else
    ROOT=
    DESTDIR=
fi

SUMMARY=
DIRINFO="# Written by setup of Vingios  $VERSION at $(date)"

###############################################################################################################
################################### FUNCTION DECLARATION START ################################################
###############################################################################################################

###############################################################################################################
# Function 1
# Funtion to create the base directory.

dir_configured ()
{
    # 
    if [ -n "$DESTDIR" ] ; then return 1 ; fi

    # Check if this path has already been configured in a previous setup
    grep -q "^$1=" $SETUPCONF >/dev/null 2>&1
}

###############################################################################################################
# Function 2
# Funtion to extract the various Vingios to Nagios binding using various aspects.

ask_dir ()
{
    if [ $1 != -d ] ; then
	prefix="$(pwd)/"
    else
	prefix=""
	shift
    fi
    VARNAME=$1
    DEF_ROOT=$2
    DEF_USER=$3
    DEF_OMD=$4
    SHORT=$5
    DESCR=$6
    eval "DIR="'$'"$VARNAME"

    if [ -n "$DESTDIR" ] ; then
	if [ -z "$DIR" ] ; then
	    DIR=$DEF_ROOT
	fi
        eval "$VARNAME='$DIR'"
    else
	if [ -z "$DIR" ] ; then
	    class="[1;44;37m default [0m"
            if [ "$OMD_SITE" ] ; then
                DEF=$DEF_OMD
	    elif [ "$ROOT" ] ; then
		DEF=$DEF_ROOT
	    else
		DEF=$DEF_USER
	    fi
	elif dir_configured "$VARNAME" ; then
	    DEF=$DIR
	    class="[1;43;37m previous [0m"
	else
	    class="[1;42;37m autodetected [0m"
	    DEF=$DIR
	fi
	PRINTOUT="$class --> [1;44;36m"
	if [ -z "$YES" ] ; then
	    read -p "[1;4m$SHORT[0m
$DESCR:
($PRINTOUT$DEF[0m): " DIR
	    if [ -z "$DIR" ] ; then DIR=$DEF ; fi
        else
	    DIR=$DEF
        fi

	# Handle relative paths
        if [ "${DIR:0:1}" != / ] ; then
	    DIR="$prefix$DIR"
        fi
        eval "$VARNAME='$DIR'"
    fi

    SUMMARY="$SUMMARY 
$(printf "[44;37m %-30s [1;45;37m %-39s [0m" "$SHORT" "$DIR")"
    DIRINFO="$DIRINFO
$VARNAME='$DIR'"
    if [ -z "$YES" ] ; then echo ; fi
}

TITLENO=0
ERRORNO=0
HOMEBASEDIR=
###############################################################################################################
# Function 3
# Function to create a bold TTILE like effect on the user screen.

ask_title ()
{
    if [ "$YES" ] ; then return ; fi
    TITLENO=$((TITLENO + 1))
    f="[44;37;1m  %-69s  [0m\n"
    echo
    printf "$f" ""
    printf "$f" "$TITLENO) $*"
    printf "$f" ""
    echo
}




ask_error ()
{
    if [ "$YES" ] ; then return ; fi
    ERRORNO=$((ERRORNO + 1))
    fe="^[[44;37;1m  %-69s  ^[[0m\n"
    echo
    echo -e '\e[1;31m';
    echo
    echo  $*
    echo
    echo -en '\e[0m'
    echo
}






install_ESpeak () {
echo "Installing Speak Module"
dpkg -i spekmodule_2.deb
dpkg -i speakModule.deb
}








install_Livestatus () {
#wget 'http://www.mathias-kettner.de/download/mk-livestatus-1.1.6p1.tar.gz'
tar xzf mk-livestatus-1.1.6p1.tar.gz
cd mk-livestatus-1.1.6p1
./configure
make
make install
cd ..
}





###############################################################################################################
################################### FUNCTION DECLARATION END ##################################################
###############################################################################################################

if [ -z "$YES" ] ; then cat <<EOF

          __            __  _______   ___      _   _________   _______    _____      _______   
          \ \          / / |__   __| |   \    | | |  _______| |__   __|  |  _  |    |  _____|  
           \ \        / /     | |    | |\ \   | | | |            | |     | | | |     \ \       
            \ \      / /      | |    | | \ \  | | | |    ___     | |     | | | |      \ \      
             \ \    / /       | |    | |  \ \ | | | |   |__ |    | |     | | | |       \ \     
              \ \_ / /      __| |__  | |   \ \| | | |_____| |  __| |__   | |_| |   _____\ \    
               \____/      |_______| |_|    \___| |_________| |_______|  |_____|  |_______|    


			   Vingios setup                  $(printf "%32s" Version:' '$VERSION)


Welcome to Vingios Nagios Virtual Voice Assistance. This setup will install Vingios into /usr/share/vingios. 
Script will handle the interaction with Nagios and Live status.

EOF

fi

if [ -z "$DESTDIR" ]
then
    if [ -n "$YES" ] ; then
	if OUTPUT=$(python $SRCDIR/autodetect.py 2>/dev/null) ; then
	    eval "$OUTPUT"
	fi
    elif OUTPUT=$(python $SRCDIR/autodetect.py)
    then
        eval "$OUTPUT"
	if [ -z "$YES" ] ; then
	    printf "[1;37;42m %-71s [0m\n" "* Found running Nagios process, autodetected $(echo "$OUTPUT" | grep -v '^\(#\|$\)' | wc -l) settings."
	fi
    fi
fi

if [ -z "$DESTDIR" -a -e "$SETUPCONF" ] && . $SETUPCONF
then
    if [ -z "$YES" ] ; then
        printf "[1;37;43m %-71s [0m\n" "* Read $(grep = $SETUPCONF | wc -l) settings from previous setup from $SETUPCONF."
    fi
fi


HOMEBASEDIR=$HOME/$NAME

ask_title "Configuration of Vingios and Nagios Communication Agent"


ask_dir nagios_binary /usr/sbin/nagios $HOMEBASEDIR/nagios/bin/nagios $OMD_ROOT/bin/nagios "Nagios binary" \
  "The complete path to the Nagios executable"

ask_dir nagios_config_file /etc/nagios/nagios.cfg $HOMEBASEDIR/nagios/etc/nagios.cfg $OMD_ROOT/tmp/nagios/nagios.cfg "Nagios main configuration file" \
  "Path to the main configuration file of Nagios"

ask_dir nagconfdir /etc/nagios/objects $HOMEBASEDIR/nagios/etc $OMD_ROOT/etc/nagios/conf.d "Nagios object directory" \
  "Nagios' object definitions for hosts, services and contacts are usually stored in various files with the extension .cfg."

ask_dir nagios_startscript /etc/init.d/nagios /etc/init.d/nagios $OMD_ROOT/etc/init.d/nagios "Nagios startskript" \
  "The complete path to the Nagios start script "

ask_dir nagpipe /var/log/nagios/rw/nagios.cmd $HOMEBASEDIR/var/nagios/rw/nagios.cmd $OMD_ROOT/tmp/run/nagios.cmd "Nagios command pipe" \
  "Complete path to the Nagios command pipe. check_mk needs write access to this pipe in order to operate"

ask_dir check_result_path /usr/local/nagios/var/spool/checkresults $HOMEBASEDIR/var/nagios/checkresults $OMD_ROOT/tmp/nagios/checkresults "Check results directory" \
  "Complete path to the directory where Nagios stores its check results."

ask_dir nagios_status_file /var/log/nagios/status.dat /var/log/nagios/status.dat $OMD_ROOT/tmp/nagios/status.dat "Nagios status file" \
  "The web pages of check_mk need to read the file 'status.dat', which is regularily created by Nagios. "

if [ -z "$YES" ]
then
    echo
    echo "----------------------------------------------------------------------"
    echo
    echo "Okay. Please confirm the below mentioned path and directories: "
    echo "$SUMMARY"
    echo 
    echo
fi




while true
do
    if [ -z "$DESTDIR" -a -z "$YES" ] ; then
        read -p "Proceed with installation (y/n)? " JA
    else
	JA=yes
    fi
    case "$JA" in
	        j|J|ja|Ja|JA|y|yes|Y|Yes|YES)

	       read -p "Now checking dependencies" JA
		echo "#########################################################################################"
		echo "Cehcking Perl, GCC and  Make  :"
			if [ -x /usr/bin/gcc ]; then
			        echo "Okay. GCC Module Installed"
				        if  [ -x /usr/bin/perl ]; then
			        	        echo "Okay. Perl Installed"
	                	                	if  [ -x /usr/bin/make ]; then
		                                        	echo "Okay. Make installed"
	        			                                if [ -x /usr/bin/g++ ]; then
                	                			                echo "Okay. G++ installed"
			        	                                else
		                                                                ask_error " Error! G++ NOT INSTALLED. PLEASE INSTALL AND RUN INSTALLER AGAIN. EXITING SETUP NOW."
			                                        	        exit 1
			                                	        fi
			                                else
                		                                ask_error " Error! MAKE NOT INSTALLED. PLEASE INSTALL AND RUN INSTALLER AGAIN. EXITING SETUP NOW."
			                                        exit  1
                        			        fi
				        else
						ask_error " Error! PERL NOT INSTALLED. PLEASE INSTALL AND RUN INSTALLER AGAIN. EXITING SETUP NOW."
				                exit 1
				        fi
			else
					ask_error  " ERROR! GCC NOT INSTALLED. PLEASEE INSTALL AND RUN INSTALLER AGAIN. EXITING SETUP NOW."
				        exit 1
			fi

		echo ""
                echo "#########################################################################################"
		echo "Extracting Nagios Version "
		nagiosversion=$(  echo "$nagios_binary" |cut -d'/' -f4)
                echo "Nagios binary is $nagiosversion. "


		echo "#########################################################################################"
		echo "Cehcking Speak Modules :"
			if [ -x /usr/bin/espeak ]; then 
				echo "Okay. Speak Module Installed"
			else
			        echo "Processing. Speak Module doesnot exist. Installer will now install Speak Modules."
    				install_ESpeak
			fi


		echo "#########################################################################################"
		echo "Cehcking Livestatus :"
			if [ -x /usr/local/lib/mk-livestatus/livestatus.o ]; then
			         echo "Okay. Livestatus Installed"
			else
				 echo "Processing. Live status doens not exist. Installer will now install Live status Modules."
				 install_Livestatus
			fi

		echo "#########################################################################################"
		echo "Processing. Appending Broker Module in $nagios_config_file file and restarting $nagiosversion :"
		echo "broker_module=/usr/local/lib/mk-livestatus/livestatus.o /var/lib/$nagiosversion/rw/live event_broker_options=-1" >>$nagios_config_file
		echo "Okay. Appending done."



                echo "#########################################################################################"
                echo "Restarting Nagios $nagiosversion "
		/etc/init.d/$nagiosversion restart
                echo "Okay. Restarting done."


		echo ""
		echo ""
		echo "#########################################################################################"
		echo "Processing. Creating Directory Structure"

			mkdir -p /usr/lib/cgi-bin/vingios
			chmod -R 777 /usr/lib/cgi-bin/vingios

			mkdir -p /vingios/cgi-bin
			chmod -R 777 /vingios/cgi-bin

			mkdir  -p  /usr/share/vingios/html
			chmod -R 777 /usr/share/vingios/html

			mkdir -p /usr/share/vingios/stylesheets
			chmod -R 777 /usr/share/vingios/stylesheets


		echo "#########################################################################################"
		echo "Processing. Copying vingios apache configuration file."
			cp vingios.conf  /etc/apache2/conf.d/
			chmod 777 /etc/apache2/conf.d/vingios.conf


			cp -R ./* /usr/share/vingios/
			cp -R ./stylesheets/* /usr/share/vingios/stylesheets/

		echo ""
		echo ""
		echo "#########################################################################################"
		echo "Processing. Deleting Temp files"
			rm -rf ./mk-livestatus-1.1.6p1



		echo ""
		echo ""
		echo "#########################################################################################"
		echo "Processing. Adding Vingios in backgroun process"
			cd /usr/share/vingios/html/
			perl ./Vingios &

		echo ""
		echo ""
		echo "#########################################################################################"
		echo "Processing. Restartig Apache server. It may affect your current apache server working status."
			/etc/init.d/apache2 restart

		#clear
		echo "#########################################################################################"
		echo " Congratulation.  Vingios Server has successfully installed."
		echo ""
		echo ""
		echo ""
		echo "  You can access Vingion on - http://localhost/vingios . Remotly access can be done by adding IP."
		echo ""
		echo "  To Start VINGIOS after every machine restart. Do the following :"  
		echo "  GOTO /usr/share/vingios/html/ and run perl Vingios &. "
		echo "  It will create to run perl in background."
		echo "  Enjoy VINGIOS"
		echo "#########################################################################################"
	   exit 1
        ;;
        n|N|no|No|Nein|nein)
        echo "Aborted."
        exit 1
        ;;
    esac
done
